@@ -28,6 +28,12 @@
 #include "chess/game_node.h"
 #include "chess/game.h"
 #include <stdlib.h>
+#ifdef __APPLE__
+#include <math.h>
+#endif
+#ifdef __linux__
+#include <math.h>
+#endif
 
 ModeController::ModeController(GameModel *gameModel, UciController *controller, QWidget *parent) :
     QObject(parent)
@@ -197,13 +203,22 @@ void ModeController::onSetEnginesClicked() {
 }
 
 void ModeController::onOptionsClicked() {
-    DialogGuiOptions *dlg = new DialogGuiOptions(this->gameModel->colorStyle, this->parentWidget);
+    ColorStyle *newColorStyle = new ColorStyle(*this->gameModel->colorStyle);
+    FontStyle *newFontStyle = new FontStyle(*this->gameModel->fontStyle);
+    DialogGuiOptions *dlg = new DialogGuiOptions(newColorStyle, newFontStyle, this->parentWidget);
     int result = dlg->exec();
     if(result == QDialog::Accepted) {
-        //this->gameModel->colorStyle = dlg->displayBoard->style;
-        this->gameModel->colorStyle = dlg->displayBoard->getColorStyle();
+        delete this->gameModel->colorStyle;
+        delete this->gameModel->fontStyle;
+        this->gameModel->colorStyle = newColorStyle;
+        this->gameModel->fontStyle = newFontStyle;
+        this->gameModel->getGame()->setTreeWasChanged(true);
         this->gameModel->triggerStateChange();
+    } else {
+        delete newColorStyle;
+        delete newFontStyle;
     }
+    delete dlg;
 }
 
 void ModeController::onStateChangeEnterMoves() {
@@ -218,6 +233,7 @@ void ModeController::onStateChangeAnalysis() {
     QString position = QString("position fen ").append(fen);
     this->uci_controller->uciSendPosition(position);
     this->uci_controller->uciGoInfinite();
+
 }
 
 void ModeController::onStateChangeGameAnalysis() {
@@ -254,12 +270,20 @@ void ModeController::onStateChangeGameAnalysis() {
     delete msg;
 }
 
+void ModeController::onMultiPVChanged(int nrLines) {
+    this->gameModel->nrPvLines = nrLines;
+    if(this->gameModel->getMode() == MODE_ANALYSIS) {
+        this->onActivateEnterMovesMode();
+        this->onActivateAnalysisMode();
+    }
+}
+
 void ModeController::onActivateAnalysisMode() {
 
     // first change gamestate and reset engine
     this->uci_controller->uciSendCommand("quit");
     QString engine_path = this->gameModel->getActiveEngine().getPath();
-    qDebug() << "engine path: " << engine_path;
+    //qDebug() << "mode contr:" << engine_path;
     this->uci_controller->startEngine(engine_path);
     this->uci_controller->uciNewgame();
     this->uci_controller->uciSendCommand("uci");
@@ -273,6 +297,8 @@ void ModeController::onActivateAnalysisMode() {
     }
     QVector<EngineOption> en_opts = this->gameModel->getActiveEngine().getUciOptions();
     this->uci_controller->sendEngineOptions(en_opts);
+    // also send multi pv command according to current selection
+    this->uci_controller->uciMultiPV(this->gameModel->nrPvLines);
     // then trigger state change
     this->gameModel->setMode(MODE_ANALYSIS);
     this->gameModel->triggerStateChange();
@@ -335,7 +361,6 @@ void ModeController::onActivateGameAnalysisMode() {
         run = true;
         this->gameModel->engineThinkTimeMs = dlg->secsPerMove;
         this->gameModel->analysisThreshold = dlg->threshold;
-        //qDebug() << this->gameModel->analysisThreshold;
         if(dlg->rbAnalyseBoth->isChecked()) {
             this->gameModel->gameAnalysisForPlayer = ANALYSE_BOTH_PLAYERS;
         } else if(dlg->rbAnalyseWhite->isChecked()) {
